@@ -1,7 +1,7 @@
-package Search::Elasticsearch::Client::5_0::Bulk;
-$Search::Elasticsearch::Client::5_0::Bulk::VERSION = '5.01';
+package Search::Elasticsearch::Client::6_0::Bulk;
+$Search::Elasticsearch::Client::6_0::Bulk::VERSION = '6.80';
 use Moo;
-with 'Search::Elasticsearch::Client::5_0::Role::Bulk',
+with 'Search::Elasticsearch::Client::6_0::Role::Bulk',
     'Search::Elasticsearch::Role::Is_Sync';
 use Search::Elasticsearch::Util qw(parse_params throw);
 use Try::Tiny;
@@ -73,11 +73,11 @@ sub flush {
 
 =head1 NAME
 
-Search::Elasticsearch::Client::5_0::Bulk - A helper module for the Bulk API
+Search::Elasticsearch::Client::6_0::Bulk - A helper module for the Bulk API
 
 =head1 VERSION
 
-version 5.01
+version 6.80
 
 =head1 SYNOPSIS
 
@@ -112,18 +112,18 @@ version 5.01
 
 =head1 DESCRIPTION
 
-This module provides a wrapper for the L<Search::Elasticsearch::Client::5_0::Direct/bulk()>
+This module provides a wrapper for the L<Search::Elasticsearch::Client::6_0::Direct/bulk()>
 method which makes it easier to run multiple create, index, update or delete
 actions in a single request.
 
-The L<Search::Elasticsearch::Client::5_0::Bulk> module acts as a queue, buffering up actions
+The L<Search::Elasticsearch::Client::6_0::Bulk> module acts as a queue, buffering up actions
 until it reaches a maximum count of actions, or a maximum size of JSON request
 body, at which point it issues a C<bulk()> request.
 
 Once you have finished adding actions, call L</flush()> to force the final
 C<bulk()> request on the items left in the queue.
 
-This class does L<Search::Elasticsearch::Client::5_0::Role::Bulk> and
+This class does L<Search::Elasticsearch::Client::6_0::Role::Bulk> and
 L<Search::Elasticsearch::Role::Is_Sync>.
 
 =head1 CREATING A NEW INSTANCE
@@ -138,7 +138,7 @@ L<Search::Elasticsearch::Role::Is_Sync>.
 
         max_count   => 1_000,               # optional
         max_size    => 1_000_000,           # optional
-        max_time    => 5,                   # optional
+        max_time    => 6,                   # optional
 
         verbose     => 0 | 1,               # optional
 
@@ -155,7 +155,7 @@ Search::Elasticsearch client as the C<es> argument.
 The C<index> and C<type> parameters provide default values for
 C<index> and C<type>, which can be overridden in each action.
 You can also pass any other values which are accepted
-by the L<bulk()|Search::Elasticsearch::Client::5_0::Direct/bulk()> method.
+by the L<bulk()|Search::Elasticsearch::Client::6_0::Direct/bulk()> method.
 
 See L</flush()> for more information about the other parameters.
 
@@ -166,7 +166,7 @@ See L</flush()> for more information about the other parameters.
     $result = $bulk->flush;
 
 The C<flush()> method sends all buffered actions to Elasticsearch using
-a L<bulk()|Search::Elasticsearch::Client::5_0::Direct/bulk()> request.
+a L<bulk()|Search::Elasticsearch::Client::6_0::Direct/bulk()> request.
 
 =head2 Auto-flushing
 
@@ -313,8 +313,8 @@ See the individual helper methods below for details.
 B<Note:> Parameters like C<index> or C<type> can be specified as C<index> or as
 C<_index>, so the following two lines are equivalent:
 
-    index => { index  => 'index', type  => 'type', id  => 1, source  => {...}},
-    index => { _index => 'index', _type => 'type', _id => 1, _source => {...}},
+    index => { index  => 'index', type  => 'type', id  => 1, source => {...}},
+    index => { _index => 'index', _type => 'type', _id => 1, source => {...}},
 
 B<Note:> The C<index> and C<type> parameters can be specified in the
 params for any action, but if not specified, will default to the C<index>
@@ -330,7 +330,7 @@ they must be specified either in L</new()> or in every action.
     );
 
 The C<create()> helper method allows you to add multiple C<create> actions.
-It accepts the same parameters as L<Search::Elasticsearch::Client::5_0::Direct/create()>
+It accepts the same parameters as L<Search::Elasticsearch::Client::6_0::Direct/create()>
 except that the document body should be passed as the C<source> or C<_source>
 parameter, instead of as C<body>.
 
@@ -356,7 +356,7 @@ you can just pass the individual document bodies.
     );
 
 The C<index()> helper method allows you to add multiple C<index> actions.
-It accepts the same parameters as L<Search::Elasticsearch::Client::5_0::Direct/index()>
+It accepts the same parameters as L<Search::Elasticsearch::Client::6_0::Direct/index()>
 except that the document body should be passed as the C<source> or C<_source>
 parameter, instead of as C<body>.
 
@@ -369,7 +369,7 @@ parameter, instead of as C<body>.
     );
 
 The C<delete()> helper method allows you to add multiple C<delete> actions.
-It accepts the same parameters as L<Search::Elasticsearch::Client::5_0::Direct/delete()>.
+It accepts the same parameters as L<Search::Elasticsearch::Client::6_0::Direct/delete()>.
 
 =head2 C<delete_ids()>
 
@@ -387,7 +387,6 @@ In this case, all you have to do is to pass in a list of IDs.
           doc_as_upsert => 1
         },
         { id            => 2,
-          lang          => 'mvel',
           script        => { script }
           upsert        => { upsert doc }
         },
@@ -395,19 +394,19 @@ In this case, all you have to do is to pass in a list of IDs.
     );
 
 The C<update()> helper method allows you to add multiple C<update> actions.
-It accepts the same parameters as L<Search::Elasticsearch::Client::5_0::Direct/update()>.
+It accepts the same parameters as L<Search::Elasticsearch::Client::6_0::Direct/update()>.
 An update can either use a I<partial doc> which gets merged with an existing
 doc (example 1 above), or can use a C<script> to update an existing doc
 (example 2 above). More information on C<script> can be found here:
-L<Search::Elasticsearch::Client::5_0::Direct/update()>.
+L<Search::Elasticsearch::Client::6_0::Direct/update()>.
 
 =head1 AUTHOR
 
-Clinton Gormley <drtech@cpan.org>
+Enrico Zimuel <enrico.zimuel@elastic.co>
 
 =head1 COPYRIGHT AND LICENSE
 
-This software is Copyright (c) 2016 by Elasticsearch BV.
+This software is Copyright (c) 2020 by Elasticsearch BV.
 
 This is free software, licensed under:
 
