@@ -1,7 +1,6 @@
 package Search::Elasticsearch::Client::6_0::Direct::ILM;
-$Search::Elasticsearch::Client::6_0::Direct::ILM::VERSION = '6.80_01'; # TRIAL
-
-$Search::Elasticsearch::Client::6_0::Direct::ILM::VERSION = '6.8001';use Moo;
+$Search::Elasticsearch::Client::6_0::Direct::ILM::VERSION = '6.80';
+use Moo;
 with 'Search::Elasticsearch::Client::6_0::Role::API';
 with 'Search::Elasticsearch::Role::Client::Direct';
 use Search::Elasticsearch::Util qw(parse_params);
@@ -20,7 +19,7 @@ Search::Elasticsearch::Client::6_0::Direct::ILM - Plugin providing index lifecyc
 
 =head1 VERSION
 
-version 6.80_01
+version 6.80
 
 =head2 DESCRIPTION
 
