@@ -1,5 +1,5 @@
 package Search::Elasticsearch::Client::6_0::Direct::Indices;
-$Search::Elasticsearch::Client::6_0::Direct::Indices::VERSION = '6.00';
+$Search::Elasticsearch::Client::6_0::Direct::Indices::VERSION = '6.80';
 use Moo;
 with 'Search::Elasticsearch::Client::6_0::Role::API';
 with 'Search::Elasticsearch::Role::Client::Direct';
@@ -17,7 +17,7 @@ Search::Elasticsearch::Client::6_0::Direct::Indices - A client for running index
 
 =head1 VERSION
 
-version 6.00
+version 6.80
 
 =head1 DESCRIPTION
 
@@ -47,6 +47,7 @@ settings, type mappings, and aliases can be added at the same time.
 Query string parameters:
     C<error_trace>,
     C<human>,
+    C<include_type_name>,
     C<master_timeout>,
     C<timeout>,
     C<update_all_types>,
@@ -73,7 +74,9 @@ Query string parameters:
     C<human>,
     C<ignore_unavailable>,
     C<include_defaults>,
-    C<local>
+    C<include_type_name>,
+    C<local>,
+    C<master_timeout>
 
 =head2 C<exists()>
 
@@ -153,7 +156,8 @@ Query string parameters:
     C<human>,
     C<ignore_unavailable>
     C<master_timeout>,
-    C<timeout>
+    C<timeout>,
+    C<wait_for_active_shards>
 
 See the L<open index docs|http://www.elastic.co/guide/en/elasticsearch/reference/current/indices-open-close.html>
 for more information.
@@ -173,6 +177,7 @@ Query string parameters:
     C<dry_run>,
     C<error_trace>,
     C<human>,
+    C<include_type_name>,
     C<master_timeout>,
     C<timeout>,
     C<wait_for_active_shards>
@@ -192,7 +197,9 @@ The shrink API shrinks the shards of an index down to a single shard (or to a fa
 of the original shards).
 
 Query string parameters:
+    C<copy_settings>,
     C<error_trace>,
+    C<filter_path>,
     C<human>,
     C<master_timeout>,
     C<timeout>,
@@ -201,6 +208,72 @@ Query string parameters:
 See the L<shrink index docs|https://www.elastic.co/guide/en/elasticsearch/reference/current/indices-shrink-index.html>
 for more information.
 
+=head2 C<split()>
+
+    $response = $e->split(
+        index  => $index,                           # required
+        target => $target,                          # required
+    );
+
+The split API splits a shard into multiple shards.
+
+Query string parameters:
+    C<copy_settings>,
+    C<error_trace>,
+    C<filter_path>,
+    C<human>,
+    C<master_timeout>,
+    C<timeout>,
+    C<wait_for_active_shards>
+
+See the L<split index docs|https://www.elastic.co/guide/en/elasticsearch/reference/current/indices-split-index.html>
+for more information.
+
+=head2 C<freeze()>
+
+    $response = $e->indices->freeze(
+        $index => $index    # required
+    );
+
+The C<freeze()> API is used to freeze an index, which puts it in a state which has almost no
+overhead on the cluster.
+
+Query string parameters:
+    C<allow_no_indices>,
+    C<error_trace>,
+    C<expand_wildcards>,
+    C<filter_path>,
+    C<human>,
+    C<ignore_unavailable>,
+    C<master_timeout>,
+    C<timeout>,
+    C<wait_for_active_shards>
+
+See the L<freeze index docs|https://www.elastic.co/guide/en/elasticsearch/reference/current/freeze-index-api.html>
+for more information.
+
+=head2 C<unfreeze()>
+
+    $response = $e->indices->unfreeze(
+        $index => $index    # required
+    );
+
+The C<unfreeze()> API is used to return a frozen index to its normal state.
+
+Query string parameters:
+    C<allow_no_indices>,
+    C<error_trace>,
+    C<expand_wildcards>,
+    C<filter_path>,
+    C<human>,
+    C<ignore_unavailable>,
+    C<master_timeout>,
+    C<timeout>,
+    C<wait_for_active_shards>
+
+See the L<unfreeze index docs|https://www.elastic.co/guide/en/elasticsearch/reference/current/freeze-index-api.html>
+for more information.
+
 =head2 C<clear_cache()>
 
     $response = $e->indices->clear_cache(
@@ -219,7 +292,6 @@ Query string parameters:
     C<human>,
     C<ignore_unavailable>,
     C<query>,
-    C<recycler>,
     C<request>
 
 See the L<clear_cache docs|http://www.elastic.co/guide/en/elasticsearch/reference/current/indices-clearcache.html>
@@ -312,8 +384,7 @@ Query string parameters:
     C<human>,
     C<ignore_unavailable>,
     C<max_num_segments>,
-    C<only_expunge_deletes>,
-    C<wait_for_merge>
+    C<only_expunge_deletes>
 
 See the L<forcemerge docs|http://www.elastic.co/guide/en/elasticsearch/reference/current/indices-forcemerge.html>
 for more information.
@@ -363,7 +434,7 @@ for more information.
 
     $response = $e->indices->put_mapping(
         index => 'index' | \@indices    # optional,
-        type  => 'type',                # required
+        type  => 'type',                # optional
 
         body  => { mapping }            # required
     )
@@ -393,6 +464,7 @@ Query string parameters:
     C<expand_wildcards>,
     C<human>,
     C<ignore_unavailable>,
+    C<include_type_name>,
     C<master_timeout>,
     C<timeout>,
     C<update_all_types>
@@ -416,7 +488,9 @@ Query string parameters:
     C<expand_wildcards>,
     C<human>,
     C<ignore_unavailable>,
-    C<local>
+    C<include_type_name>,
+    C<local>,
+    C<master_timeout>
 
 See the L<get_mapping docs|http://www.elastic.co/guide/en/elasticsearch/reference/current/indices-get-mapping.html>
 for more information.
@@ -441,6 +515,7 @@ Query string parameters:
     C<human>,
     C<ignore_unavailable>,
     C<include_defaults>,
+    C<include_type_name>,
     C<local>
 
 See the L<get_mapping docs|http://www.elastic.co/guide/en/elasticsearch/reference/current/indices-get-field-mapping.html>
@@ -549,7 +624,7 @@ for more information.
 
     $bool = $e->indices->exists_alias(
         index   => 'index' | \@indices,     # optional
-        name    => 'alias' | \@aliases      # optional
+        name    => 'alias' | \@aliases      # required
     );
 
 The C<exists_alias()> method returns C<1> or the empty string depending on
@@ -612,7 +687,8 @@ Query string parameters:
     C<human>,
     C<ignore_unavailable>,
     C<master_timeout>,
-    C<preserve_existing>
+    C<preserve_existing>,
+    C<timeout>
 
 See the L<put_settings docs|http://www.elastic.co/guide/en/elasticsearch/reference/current/indices-update-settings.html>
 for more information.
@@ -635,7 +711,8 @@ Query string parameters:
     C<human>,
     C<ignore_unavailable>,
     C<include_defaults>,
-    C<local>
+    C<local>,
+    C<master_timeout>
 
 See the L<get_settings docs|http://www.elastic.co/guide/en/elasticsearch/reference/current/indices-get-settings.html>
 for more information.
@@ -656,12 +733,10 @@ Query string parameters:
     C<error_trace>,
     C<flat_settings>,
     C<human>,
+    C<include_type_name>,
     C<master_timeout>,
-    C<op_type>,
     C<order>,
-    C<timeout>,
-    C<version>,
-    C<version_type>
+    C<timeout>
 
 See the L<put_template docs|http://www.elastic.co/guide/en/elasticsearch/reference/current/indices-templates.html>
 for more information.
@@ -678,6 +753,7 @@ Query string parameters:
     C<error_trace>,
     C<flat_settings>,
     C<human>,
+    C<include_type_name>,
     C<local>,
     C<master_timeout>
 
@@ -840,8 +916,7 @@ for debugging analyzer configurations.
 
 Query string parameters:
     C<error_trace>,
-    C<format>,
-    C<prefer_local>
+    C<human>
 
 See the L<analyze docs|http://www.elastic.co/guide/en/elasticsearch/reference/current/indices-analyze.html>
 for more information.
@@ -879,11 +954,11 @@ for more information.
 
 =head1 AUTHOR
 
-Clinton Gormley <drtech@cpan.org>
+Enrico Zimuel <enrico.zimuel@elastic.co>
 
 =head1 COPYRIGHT AND LICENSE
 
-This software is Copyright (c) 2017 by Elasticsearch BV.
+This software is Copyright (c) 2020 by Elasticsearch BV.
 
 This is free software, licensed under:
 
