@@ -1,7 +1,6 @@
 package Search::Elasticsearch::Client::6_0::Direct::XPack::Monitoring;
-$Search::Elasticsearch::Client::6_0::Direct::XPack::Monitoring::VERSION = '6.80_01'; # TRIAL
-
-$Search::Elasticsearch::Client::6_0::Direct::XPack::Monitoring::VERSION = '6.8001';use Moo;
+$Search::Elasticsearch::Client::6_0::Direct::XPack::Monitoring::VERSION = '6.80';
+use Moo;
 with 'Search::Elasticsearch::Client::6_0::Role::API';
 with 'Search::Elasticsearch::Role::Client::Direct';
 use namespace::clean;
@@ -24,7 +23,7 @@ Search::Elasticsearch::Client::6_0::Direct::XPack::Monitoring - Plugin providing
 
 =head1 VERSION
 
-version 6.80_01
+version 6.80
 
 =head1 SYNOPSIS
 
