@@ -1,7 +1,6 @@
 package Search::Elasticsearch::Client::6_0::Role::Bulk;
-$Search::Elasticsearch::Client::6_0::Role::Bulk::VERSION = '6.80_1'; # TRIAL
-
-$Search::Elasticsearch::Client::6_0::Role::Bulk::VERSION = '6.801';use Moo::Role;
+$Search::Elasticsearch::Client::6_0::Role::Bulk::VERSION = '6.80';
+use Moo::Role;
 requires 'add_action', 'flush';
 
 use Search::Elasticsearch::Util qw(parse_params throw);
@@ -275,7 +274,7 @@ Search::Elasticsearch::Client::6_0::Role::Bulk - Provides common functionality t
 
 =head1 VERSION
 
-version 6.80_1
+version 6.80
 
 =head1 AUTHOR
 
