@@ -1,7 +1,6 @@
 package Search::Elasticsearch::Cxn::Factory;
-$Search::Elasticsearch::Cxn::Factory::VERSION = '6.80_1'; # TRIAL
-
-$Search::Elasticsearch::Cxn::Factory::VERSION = '6.801';use Moo;
+$Search::Elasticsearch::Cxn::Factory::VERSION = '6.80';
+use Moo;
 use Search::Elasticsearch::Util qw(parse_params load_plugin);
 use namespace::clean;
 
@@ -48,7 +47,7 @@ Search::Elasticsearch::Cxn::Factory - Used by CxnPools to create new Cxn instanc
 
 =head1 VERSION
 
-version 6.80_1
+version 6.80
 
 =head1 DESCRIPTION
 
