@@ -1,7 +1,6 @@
 package Search::Elasticsearch::Cxn::HTTPTiny;
-$Search::Elasticsearch::Cxn::HTTPTiny::VERSION = '6.80_01'; # TRIAL
-
-$Search::Elasticsearch::Cxn::HTTPTiny::VERSION = '6.8001';use Moo;
+$Search::Elasticsearch::Cxn::HTTPTiny::VERSION = '6.80';
+use Moo;
 with 'Search::Elasticsearch::Role::Cxn', 'Search::Elasticsearch::Role::Is_Sync';
 
 use HTTP::Tiny 0.043 ();
@@ -86,7 +85,7 @@ Search::Elasticsearch::Cxn::HTTPTiny - A Cxn implementation which uses HTTP::Tin
 
 =head1 VERSION
 
-version 6.80_01
+version 6.80
 
 =head1 DESCRIPTION
 
