@@ -1,7 +1,6 @@
 package Search::Elasticsearch::Cxn::Hijk;
-$Search::Elasticsearch::Cxn::Hijk::VERSION = '6.80_01'; # TRIAL
-
-$Search::Elasticsearch::Cxn::Hijk::VERSION = '6.8001';use Moo;
+$Search::Elasticsearch::Cxn::Hijk::VERSION = '6.80';
+use Moo;
 with 'Search::Elasticsearch::Role::Cxn', 'Search::Elasticsearch::Role::Is_Sync';
 
 use Hijk 0.27;
@@ -123,7 +122,7 @@ Search::Elasticsearch::Cxn::Hijk - A Cxn implementation which uses Hijk
 
 =head1 VERSION
 
-version 6.80_01
+version 6.80
 
 =head1 DESCRIPTION
 
