@@ -1,7 +1,6 @@
 package Search::Elasticsearch::Cxn::LWP;
-$Search::Elasticsearch::Cxn::LWP::VERSION = '6.80_1'; # TRIAL
-
-$Search::Elasticsearch::Cxn::LWP::VERSION = '6.801';use Moo;
+$Search::Elasticsearch::Cxn::LWP::VERSION = '6.80';
+use Moo;
 with 'Search::Elasticsearch::Role::Cxn', 'Search::Elasticsearch::Role::Is_Sync';
 
 use LWP::UserAgent();
@@ -29,13 +28,11 @@ sub perform_request {
         $headers{'Content-Encoding'} = $params->{encoding}
             if $params->{encoding};
     }
-
     my $request = HTTP::Request->new(
         $method => $uri,
         [ %headers, %{ $self->default_headers }, ],
         $params->{data}
     );
-
     my $ua = $self->handle;
     my $timeout = $params->{timeout} || $self->request_timeout;
     if ( $timeout ne $ua->timeout ) {
@@ -77,7 +74,7 @@ sub _build_handle {
         $args{ssl_opts}
             = $self->has_ssl_options
             ? $self->ssl_options
-            : { verify_hostname => 0 };
+            : { verify_hostname => 0, SSL_verify_mode => 0x00 };
     }
     return LWP::UserAgent->new( %args, %{ $self->handle_args } );
 }
@@ -98,7 +95,7 @@ Search::Elasticsearch::Cxn::LWP - A Cxn implementation which uses LWP
 
 =head1 VERSION
 
-version 6.80_1
+version 6.80
 
 =head1 DESCRIPTION
 
