@@ -1,7 +1,6 @@
 package Search::Elasticsearch::CxnPool::Sniff;
-$Search::Elasticsearch::CxnPool::Sniff::VERSION = '6.80_1'; # TRIAL
-
-$Search::Elasticsearch::CxnPool::Sniff::VERSION = '6.801';use Moo;
+$Search::Elasticsearch::CxnPool::Sniff::VERSION = '6.80';
+use Moo;
 with 'Search::Elasticsearch::Role::CxnPool::Sniff',
     'Search::Elasticsearch::Role::Is_Sync';
 
@@ -82,7 +81,7 @@ Search::Elasticsearch::CxnPool::Sniff - A CxnPool for connecting to a local clus
 
 =head1 VERSION
 
-version 6.80_1
+version 6.80
 
 =head1 SYNOPSIS
 
