@@ -1,7 +1,6 @@
 package Search::Elasticsearch::CxnPool::Static;
-$Search::Elasticsearch::CxnPool::Static::VERSION = '6.80_01'; # TRIAL
-
-$Search::Elasticsearch::CxnPool::Static::VERSION = '6.8001';use Moo;
+$Search::Elasticsearch::CxnPool::Static::VERSION = '6.80';
+use Moo;
 with 'Search::Elasticsearch::Role::CxnPool::Static',
     'Search::Elasticsearch::Role::Is_Sync';
 use Search::Elasticsearch::Util qw(throw);
@@ -51,7 +50,7 @@ Search::Elasticsearch::CxnPool::Static - A CxnPool for connecting to a remote cl
 
 =head1 VERSION
 
-version 6.80_01
+version 6.80
 
 =head1 SYNOPSIS
 
