@@ -1,7 +1,6 @@
 package Search::Elasticsearch::CxnPool::Static::NoPing;
-$Search::Elasticsearch::CxnPool::Static::NoPing::VERSION = '6.80_1'; # TRIAL
-
-$Search::Elasticsearch::CxnPool::Static::NoPing::VERSION = '6.801';use Moo;
+$Search::Elasticsearch::CxnPool::Static::NoPing::VERSION = '6.80';
+use Moo;
 with 'Search::Elasticsearch::Role::CxnPool::Static::NoPing',
     'Search::Elasticsearch::Role::Is_Sync';
 use Search::Elasticsearch::Util qw(throw);
@@ -19,7 +18,7 @@ Search::Elasticsearch::CxnPool::Static::NoPing - A CxnPool for connecting to a r
 
 =head1 VERSION
 
-version 6.80_1
+version 6.80
 
 =head1 SYNOPSIS
 
