@@ -1,7 +1,6 @@
 package Search::Elasticsearch::Error;
-$Search::Elasticsearch::Error::VERSION = '6.80_1'; # TRIAL
-
-$Search::Elasticsearch::Error::VERSION = '6.801';our $DEBUG = 0;
+$Search::Elasticsearch::Error::VERSION = '6.80';
+our $DEBUG = 0;
 
 @Search::Elasticsearch::Error::Internal::ISA     = __PACKAGE__;
 @Search::Elasticsearch::Error::Param::ISA        = __PACKAGE__;
@@ -180,7 +179,7 @@ Search::Elasticsearch::Error - Errors thrown by Search::Elasticsearch
 
 =head1 VERSION
 
-version 6.80_1
+version 6.80
 
 =head1 DESCRIPTION
 
