@@ -1,7 +1,6 @@
 package Search::Elasticsearch::Logger::LogAny;
-$Search::Elasticsearch::Logger::LogAny::VERSION = '6.80_01'; # TRIAL
-
-$Search::Elasticsearch::Logger::LogAny::VERSION = '6.8001';use Moo;
+$Search::Elasticsearch::Logger::LogAny::VERSION = '6.80';
+use Moo;
 with 'Search::Elasticsearch::Role::Logger';
 use Search::Elasticsearch::Util qw(parse_params to_list);
 use namespace::clean;
@@ -58,7 +57,7 @@ Search::Elasticsearch::Logger::LogAny - A Log::Any-based Logger implementation
 
 =head1 VERSION
 
-version 6.80_01
+version 6.80
 
 =head1 DESCRIPTION
 
