@@ -1,7 +1,6 @@
 package Search::Elasticsearch::Role::API;
-$Search::Elasticsearch::Role::API::VERSION = '6.80_01'; # TRIAL
-
-$Search::Elasticsearch::Role::API::VERSION = '6.8001';use Moo::Role;
+$Search::Elasticsearch::Role::API::VERSION = '6.80';
+use Moo::Role;
 requires 'api_version';
 requires 'api';
 
@@ -96,7 +95,7 @@ Search::Elasticsearch::Role::API - Provides common functionality for API impleme
 
 =head1 VERSION
 
-version 6.80_01
+version 6.80
 
 =head1 AUTHOR
 
