@@ -1,7 +1,6 @@
 package Search::Elasticsearch::Role::Client;
-$Search::Elasticsearch::Role::Client::VERSION = '6.80_1'; # TRIAL
-
-$Search::Elasticsearch::Role::Client::VERSION = '6.801';use Moo::Role;
+$Search::Elasticsearch::Role::Client::VERSION = '6.80';
+use Moo::Role;
 use namespace::clean;
 
 requires 'parse_request';
@@ -29,7 +28,7 @@ Search::Elasticsearch::Role::Client - Provides common functionality for Client i
 
 =head1 VERSION
 
-version 6.80_1
+version 6.80
 
 =head1 DESCRIPTION
 
