@@ -1,7 +1,6 @@
 package Search::Elasticsearch::Role::Client::Direct;
-$Search::Elasticsearch::Role::Client::Direct::VERSION = '6.80_1'; # TRIAL
-
-$Search::Elasticsearch::Role::Client::Direct::VERSION = '6.801';use Moo::Role;
+$Search::Elasticsearch::Role::Client::Direct::VERSION = '6.80';
+use Moo::Role;
 with 'Search::Elasticsearch::Role::Client';
 use Search::Elasticsearch::Util qw(load_plugin is_compat throw);
 
@@ -176,7 +175,7 @@ Search::Elasticsearch::Role::Client::Direct - Request parsing for Direct clients
 
 =head1 VERSION
 
-version 6.80_1
+version 6.80
 
 =head1 DESCRIPTION
 
