@@ -1,7 +1,6 @@
 package Search::Elasticsearch::Role::Cxn;
-$Search::Elasticsearch::Role::Cxn::VERSION = '6.80_1'; # TRIAL
-
-$Search::Elasticsearch::Role::Cxn::VERSION = '6.801';use Moo::Role;
+$Search::Elasticsearch::Role::Cxn::VERSION = '6.80';
+use Moo::Role;
 use Search::Elasticsearch::Util qw(parse_params throw to_list);
 use List::Util qw(min);
 use Try::Tiny;
@@ -62,7 +61,7 @@ sub stringify { shift->uri . '' }
 #===================================
 sub get_user_agent {
 #===================================
-    return sprintf("elasticsearch-perl/%s- (PERL %s)", $Search::Elasticsearch::VERSION, $]);
+    return sprintf("elasticsearch-perl/%s (%s; perl %s)", $Search::Elasticsearch::VERSION, $^O, $]);
 }
 
 #===================================
@@ -430,7 +429,7 @@ Search::Elasticsearch::Role::Cxn - Provides common functionality to HTTP Cxn imp
 
 =head1 VERSION
 
-version 6.80_1
+version 6.80
 
 =head1 DESCRIPTION
 
