@@ -1,7 +1,6 @@
 package Search::Elasticsearch::Role::CxnPool;
-$Search::Elasticsearch::Role::CxnPool::VERSION = '6.80_01'; # TRIAL
-
-$Search::Elasticsearch::Role::CxnPool::VERSION = '6.8001';use Moo::Role;
+$Search::Elasticsearch::Role::CxnPool::VERSION = '6.80';
+use Moo::Role;
 use Search::Elasticsearch::Util qw(parse_params);
 use List::Util qw(shuffle);
 use IO::Select();
@@ -135,7 +134,7 @@ Search::Elasticsearch::Role::CxnPool - Provides common functionality to the CxnP
 
 =head1 VERSION
 
-version 6.80_01
+version 6.80
 
 =head1 DESCRIPTION
 
