@@ -1,7 +1,6 @@
 package Search::Elasticsearch::Role::CxnPool::Sniff;
-$Search::Elasticsearch::Role::CxnPool::Sniff::VERSION = '6.80_01'; # TRIAL
-
-$Search::Elasticsearch::Role::CxnPool::Sniff::VERSION = '6.8001';use Moo::Role;
+$Search::Elasticsearch::Role::CxnPool::Sniff::VERSION = '6.80';
+use Moo::Role;
 with 'Search::Elasticsearch::Role::CxnPool';
 requires 'next_cxn', 'sniff';
 use namespace::clean;
@@ -98,7 +97,7 @@ Search::Elasticsearch::Role::CxnPool::Sniff - A CxnPool role for connecting to a
 
 =head1 VERSION
 
-version 6.80_01
+version 6.80
 
 =head1 CONFIGURATION
 
