@@ -1,7 +1,6 @@
 package Search::Elasticsearch::Role::CxnPool::Static;
-$Search::Elasticsearch::Role::CxnPool::Static::VERSION = '6.80_01'; # TRIAL
-
-$Search::Elasticsearch::Role::CxnPool::Static::VERSION = '6.8001';use Moo::Role;
+$Search::Elasticsearch::Role::CxnPool::Static::VERSION = '6.80';
+use Moo::Role;
 with 'Search::Elasticsearch::Role::CxnPool';
 requires 'next_cxn';
 
@@ -40,7 +39,7 @@ Search::Elasticsearch::Role::CxnPool::Static - A CxnPool role for connecting to
 
 =head1 VERSION
 
-version 6.80_01
+version 6.80
 
 =head1 METHODS
 
