@@ -1,7 +1,6 @@
 package Search::Elasticsearch::Role::CxnPool::Static::NoPing;
-$Search::Elasticsearch::Role::CxnPool::Static::NoPing::VERSION = '6.80_01'; # TRIAL
-
-$Search::Elasticsearch::Role::CxnPool::Static::NoPing::VERSION = '6.8001';use Moo::Role;
+$Search::Elasticsearch::Role::CxnPool::Static::NoPing::VERSION = '6.80';
+use Moo::Role;
 with 'Search::Elasticsearch::Role::CxnPool';
 
 use namespace::clean;
@@ -80,7 +79,7 @@ Search::Elasticsearch::Role::CxnPool::Static::NoPing - A CxnPool for connecting
 
 =head1 VERSION
 
-version 6.80_01
+version 6.80
 
 =head1 AUTHOR
 
