@@ -1,7 +1,6 @@
 package Search::Elasticsearch::Role::Is_Sync;
-$Search::Elasticsearch::Role::Is_Sync::VERSION = '6.80_01'; # TRIAL
-
-$Search::Elasticsearch::Role::Is_Sync::VERSION = '6.8001';use Moo::Role;
+$Search::Elasticsearch::Role::Is_Sync::VERSION = '6.80';
+use Moo::Role;
 use namespace::clean;
 
 1;
@@ -20,7 +19,7 @@ Search::Elasticsearch::Role::Is_Sync - A role to mark classes which should be us
 
 =head1 VERSION
 
-version 6.80_01
+version 6.80
 
 =head1 AUTHOR
 
