@@ -1,7 +1,6 @@
 package Search::Elasticsearch::Role::Logger;
-$Search::Elasticsearch::Role::Logger::VERSION = '6.80_01'; # TRIAL
-
-$Search::Elasticsearch::Role::Logger::VERSION = '6.8001';use Moo::Role;
+$Search::Elasticsearch::Role::Logger::VERSION = '6.80';
+use Moo::Role;
 
 use URI();
 use Try::Tiny;
@@ -155,7 +154,7 @@ Search::Elasticsearch::Role::Logger - Provides common functionality to Logger im
 
 =head1 VERSION
 
-version 6.80_01
+version 6.80
 
 =head1 DESCRIPTION
 
