@@ -1,7 +1,6 @@
 package Search::Elasticsearch::Role::Serializer;
-$Search::Elasticsearch::Role::Serializer::VERSION = '6.80_1'; # TRIAL
-
-$Search::Elasticsearch::Role::Serializer::VERSION = '6.801';use Moo::Role;
+$Search::Elasticsearch::Role::Serializer::VERSION = '6.80';
+use Moo::Role;
 
 requires qw(encode decode encode_pretty encode_bulk mime_type);
 
@@ -21,7 +20,7 @@ Search::Elasticsearch::Role::Serializer - An interface for Serializer modules
 
 =head1 VERSION
 
-version 6.80_1
+version 6.80
 
 =head1 DESCRIPTION
 
