@@ -1,7 +1,6 @@
 package Search::Elasticsearch::Role::Serializer::JSON;
-$Search::Elasticsearch::Role::Serializer::JSON::VERSION = '6.80_01'; # TRIAL
-
-$Search::Elasticsearch::Role::Serializer::JSON::VERSION = '6.8001';use Moo::Role;
+$Search::Elasticsearch::Role::Serializer::JSON::VERSION = '6.80';
+use Moo::Role;
 requires 'JSON';
 
 use Search::Elasticsearch::Util qw(throw);
@@ -104,7 +103,7 @@ Search::Elasticsearch::Role::Serializer::JSON - A Serializer role for JSON modul
 
 =head1 VERSION
 
-version 6.80_01
+version 6.80
 
 =head1 DESCRIPTION
 
