@@ -1,7 +1,6 @@
 package Search::Elasticsearch::Role::Transport;
-$Search::Elasticsearch::Role::Transport::VERSION = '6.80_1'; # TRIAL
-
-$Search::Elasticsearch::Role::Transport::VERSION = '6.801';use Moo::Role;
+$Search::Elasticsearch::Role::Transport::VERSION = '6.80';
+use Moo::Role;
 
 requires qw(perform_request);
 
@@ -73,7 +72,7 @@ Search::Elasticsearch::Role::Transport - Transport role providing interface betw
 
 =head1 VERSION
 
-version 6.80_1
+version 6.80
 
 =head1 AUTHOR
 
