@@ -1,7 +1,6 @@
 package Search::Elasticsearch::Serializer::JSON;
-$Search::Elasticsearch::Serializer::JSON::VERSION = '6.80_01'; # TRIAL
-
-$Search::Elasticsearch::Serializer::JSON::VERSION = '6.8001';use Moo;
+$Search::Elasticsearch::Serializer::JSON::VERSION = '6.80';
+use Moo;
 use JSON::MaybeXS 1.002002 ();
 
 has 'JSON' => ( is => 'ro', default => sub { JSON::MaybeXS->new->utf8(1) } );
@@ -25,7 +24,7 @@ Search::Elasticsearch::Serializer::JSON - The default JSON Serializer, using JSO
 
 =head1 VERSION
 
-version 6.80_01
+version 6.80
 
 =head1 SYNOPSIS
 
