@@ -1,7 +1,6 @@
 package Search::Elasticsearch::Serializer::JSON::Cpanel;
-$Search::Elasticsearch::Serializer::JSON::Cpanel::VERSION = '6.80_1'; # TRIAL
-
-$Search::Elasticsearch::Serializer::JSON::Cpanel::VERSION = '6.801';use Cpanel::JSON::XS;
+$Search::Elasticsearch::Serializer::JSON::Cpanel::VERSION = '6.80';
+use Cpanel::JSON::XS;
 use Moo;
 
 has 'JSON' =>
@@ -21,7 +20,7 @@ Search::Elasticsearch::Serializer::JSON::Cpanel - A JSON Serializer using Cpanel
 
 =head1 VERSION
 
-version 6.80_1
+version 6.80
 
 =head1 SYNOPSIS
 
