@@ -1,7 +1,6 @@
 package Search::Elasticsearch::Serializer::JSON::PP;
-$Search::Elasticsearch::Serializer::JSON::PP::VERSION = '6.80_01'; # TRIAL
-
-$Search::Elasticsearch::Serializer::JSON::PP::VERSION = '6.8001';use Moo;
+$Search::Elasticsearch::Serializer::JSON::PP::VERSION = '6.80';
+use Moo;
 use JSON::PP;
 
 has 'JSON' => ( is => 'ro', default => sub { JSON::PP->new->utf8(1) } );
@@ -24,7 +23,7 @@ Search::Elasticsearch::Serializer::JSON::PP - A JSON Serializer using JSON::PP
 
 =head1 VERSION
 
-version 6.80_01
+version 6.80
 
 =head1 SYNOPSIS
 
