@@ -1,7 +1,6 @@
 package Search::Elasticsearch::Serializer::JSON::XS;
-$Search::Elasticsearch::Serializer::JSON::XS::VERSION = '6.80_1'; # TRIAL
-
-$Search::Elasticsearch::Serializer::JSON::XS::VERSION = '6.801';use Moo;
+$Search::Elasticsearch::Serializer::JSON::XS::VERSION = '6.80';
+use Moo;
 use JSON::XS 2.26;
 
 has 'JSON' => ( is => 'ro', default => sub { JSON::XS->new->utf8(1) } );
@@ -20,7 +19,7 @@ Search::Elasticsearch::Serializer::JSON::XS - A JSON Serializer using JSON::XS
 
 =head1 VERSION
 
-version 6.80_1
+version 6.80
 
 =head1 SYNOPSIS
 
