@@ -1,7 +1,6 @@
 package Search::Elasticsearch::TestServer;
-$Search::Elasticsearch::TestServer::VERSION = '6.80_1'; # TRIAL
-
-$Search::Elasticsearch::TestServer::VERSION = '6.801';use Moo;
+$Search::Elasticsearch::TestServer::VERSION = '6.80';
+use Moo;
 use Search::Elasticsearch();
 use POSIX 'setsid';
 use File::Temp();
@@ -195,7 +194,7 @@ Search::Elasticsearch::TestServer - A helper class to launch Elasticsearch nodes
 
 =head1 VERSION
 
-version 6.80_1
+version 6.80
 
 =head1 SYNOPSIS
 
