@@ -1,7 +1,6 @@
 package Search::Elasticsearch::Transport;
-$Search::Elasticsearch::Transport::VERSION = '6.80_01'; # TRIAL
-
-$Search::Elasticsearch::Transport::VERSION = '6.8001';use Moo;
+$Search::Elasticsearch::Transport::VERSION = '6.80';
+use Moo;
 
 use URI();
 use Time::HiRes qw(time);
@@ -73,7 +72,7 @@ Search::Elasticsearch::Transport - Provides interface between the client class a
 
 =head1 VERSION
 
-version 6.80_01
+version 6.80
 
 =head1 DESCRIPTION
 
