@@ -1,7 +1,6 @@
 package Search::Elasticsearch::Util;
-$Search::Elasticsearch::Util::VERSION = '6.80_1'; # TRIAL
-
-$Search::Elasticsearch::Util::VERSION = '6.801';use Moo;
+$Search::Elasticsearch::Util::VERSION = '6.80';
+use Moo;
 use Search::Elasticsearch::Error();
 use Scalar::Util qw(blessed);
 use Module::Runtime qw(compose_module_name is_module_name use_module);
@@ -120,7 +119,7 @@ Search::Elasticsearch::Util - A utility class for internal use by Search::Elasti
 
 =head1 VERSION
 
-version 6.80_1
+version 6.80
 
 =head1 AUTHOR
 
